package taximod.example;

import net.mosgrom.taxi.module.BaseModule;

/**
 * All mods must implement a Module class and it must always be called "Main" and be placed directly under the mod's
 * root package. So if you're mod is called "Stimpy's Mod" then, first of all you can't use spaces, special characters
 * or capital letter (you can of course refer to it online anyway you want) so the "technical" name should maybe be
 * "stimpysmod". The Main Module class is then "taximod.stimpysmod.Main". Somebody else's mod might be called "bobcat"
 * their Main Module class will be "taximod.bobcat.Main". Here the mod is called "example" so the Module class is
 * "taximod.example.Main".<br/>
 * <br/>
 * Each Module must also specify it's id (by returning it from its id() method implementation). Module ids [0-100] are
 * reserved for myself (mosgrom) and I've used 101 for this example. Modules need unique ids and there's no way to
 * automate this (I won't go into why here but in short: it should enable mixing of mods and modders refering to
 * content in eachother's mods without problems). In the future I will place a list online with "used" mod ids and you
 * should pick one that isn't used and let me know (mosgrom@mosgrom.net). For now just pick 100. (I've used 101 here
 * for the example).<br/>
 * <br/>
 * The Main class specifies and loads all the LoaderPlugins that define "types of things" like SiteDefinitions (define
 * the buildings, trees, traders, etc. you see on planets), SetDefinitions (define overall planets, stations, caves,
 * etc. but also sets of traders, etc.), NPCDefinitions (define NPCs), and so on. Instances of things in the game have
 * some kind of definition (that was defined and added through a loader) associated with them.<br/>
 * <br/>
 * When you derive your Main class for BaseModule (which you should) then you only have to specify the LoaderPlugin.
 * For example below the siteDefinitionLoaders() method must return all LoaderPlugins that add SiteDefinitions to the
 * game (normally you will only need one of those). Here it specifies "taxiplg.example.SiteLoader" which corresponds to
 * that class in this example mod project (src/taxiplg/example/SitesLoader.java).<br/>
 * <br/>
 * IMPORTANT: Modules (and other classes under the taximod package) once referenced will remain loaded in the game.
 * Plugins (classes under taxiplg package) will not. That's why, for example, definitions aren't simply defined and
 * loaded right here in the Module's code. The definition and loading of them is done in Plugins which this Module
 * specifies. After each Plugin is done defining things and adding them to the game (or whatever it does) it is
 * unloaded because its not needed anymore. There are also DialogPlugins UIPlugins etc. Basically Plugins should be
 * seen as scripts that are run and then discarded when finished.
 * 
 * Items, etc.
 * 
 * @author jasper
 *
 */
public class Main extends BaseModule {

	@Override
	public int id() {
		//The id of the "example" mod is 101 this number must also be used as the name for its dat directory etc.
		return 101;
	}

	@Override
	protected String[] siteDefinitionLoaders() {
		//The Plugin that defines and adds the SiteDefinitions in the example mod (e.g. the pyramid and dome sites).
		return new String[] {"taxiplg.example.SitesLoader"};
	}

	@Override
	protected String[] setDefinitionLoaders() {
		//The Plugin that defines and adds the SetDefinitions in the example mod (e.g. the Domo planet
		//ZoneSetDefinition).
		return new String[] {"taxiplg.example.SiteSetsLoader"};
	}

	@Override
	protected String[] itemLoaders() {
		//The Plugin that defines and adds the Items in the example mod (e.g. the "domocast" Item).
		return new String[] {"taxiplg.example.ItemsLoader"};
	}

	@Override
	public String[] setupPluginLoaders() {
		//The Plugin that specifies any SetupPlugins used by the example mod.
		return new String[] {"taxiplg.example.SetupsLoader"};
	}
	
}
