package taxiplg.example;

import net.mosgrom.taxi.SaveFileDatabase.SaveFile;
import net.mosgrom.taxi.Taxi;
import net.mosgrom.taxi.plugin.BaseSetupPlugin;
import net.mosgrom.util.BitMap;

/**
 * Setup Plugins allow you to do all kinds of extra things after a game (galaxy and player) have been generated or
 * loaded. You can do things here like hard-place instances of certain ZoneSetDefinitions (planets) or setup certain
 * things on Items that need something done when they are first added to the game (e.g. the "hungry" Item in Taxinaut
 * schedules its first occurrence in this way). They are also used (and responsible) for managing differences between
 * version of Taxinaut and/or versions of mods. For example you can't just change a planet's ZoneSetDefinitions that
 * has been used in active games before (it can break the generation of the planet) the maintainer (modder) will have
 * to do some things to work around this. There's too much to say about this to get into this right now.<br/>
 * <br/>
 * Here in example this simply adds the "domcast" Item to the Player so they can use it to teleport to planet Domo. Pay
 * attention to the Setup() constructor. It must specify a numeric id for itself that must be in the id range of the
 * Module that uses this SetupPlugin. For "example" the Module id is 101 and thus the id range is [1010000-1019999].
 * Each Module can use 10000 ids. Same type things from the same Module cannot have the same id but different type
 * things can. For example two SiteDefinitions cannot both have id 170001 but a SiteDefinition, a SetupPlugin and a
 * MobDefinition can all have id 170001. This allows each mod to defined 10000 different things for each type (10000
 * SiteDefinitions, 10000 MobDefinitions, etc.).
 * 
 * @author jasper
 *
 */
public class Setup extends BaseSetupPlugin {

	public Setup() {
		//Calls the constructor of BaseSetupPlugin which sets the id for this SetupPlugin to 1010000 and the version to
		//1. If you change this SetupPlugin and it was already used on active games out there then you should change
		//the version so you can keep track of what things (in run(...)) where already done (see the use of the
		//'last_run_version' parameter below in the run(...) method).
		super(1010000, 1);
	}

	@Override
	public void run(int last_run_version, SaveFile sf, Taxi app, BitMap sector_occupied_map) {
		//First check that the game currently being loaded didn't already have this version of the setup run on it or
		//else "domocast" would be added to the Player again (which does nothing because domocast is a singleton but it
		//demonstrates the possible use of the 'last_run_version' parameter).
		if (last_run_version < 1) {
			app.player.add("domocast");
		}
	}

}
