package taxiplg.example;

import net.mosgrom.taxi.Taxi;
import net.mosgrom.taxi.dat.EnvironmentDefinition;
import net.mosgrom.taxi.dat.SetDefinitionRepository;
import net.mosgrom.taxi.dat.ZoneSetDefinition;
import net.mosgrom.taxi.plugin.SetDefinitionLoader;

/**
 * Defines and loads the SetDefinitions (e.g. planet types) for the "example" mod.
 * 
 * @author jasper
 *
 */
public class SiteSetsLoader implements SetDefinitionLoader {

	@Override
	public void load(SetDefinitionRepository repo, Taxi app) throws Exception {
		
		{
			//Definition of the planet type for Domo. 1010000 is the id of this ZoneSetDefinition (other things like for
			//example DialogPlugins when giving directions etc. can refer to planets of this ZoneSetDefinition by this
			//id. (See for example taximod.example.Domocast that uses it to teleport to Domo).
			ZoneSetDefinition sed = new ZoneSetDefinition(1010000);
			sed.name("Domo");
			
			//This adds the pyramid site (as defined in taxiplg.example.SitesLoader) with weight 1.
			sed.addSite(1010000, 1);
			//This adds the dome site (as defined in taxiplg.example.SitesLoader) with weight 3 (which means there will
			//be about 3 times more domes than pyramids).
			sed.addSite(1010001, 3);
			
			//Means (by default) that only 1 planet of this ZoneSetDefinition is placed in the galaxy.
			sed.rating(5);
			
			//Sets up the land & water colors and ratio and fog levels.
			EnvironmentDefinition env = new EnvironmentDefinition(sed);
			env.addGoodColor(61, 72, 57, 255, 85, 128, 103, 255, 0, 75);
			sed.environment(env);
			
			//71 refers to a SetDefinition in the basic mosgrom Module (Module id=0) that defines a bunch of standard
			//shops and bars, etc.
			sed.traders(71);
			
			//Don't forget to actually add the ZoneSetDefinition to the SetDefinitionRepository.
			repo.add(sed);
		}
		
	}

}
